@@ -1,8 +1,11 @@
 package Plack::Middleware::LogHarakiri;
-$Plack::Middleware::LogHarakiri::VERSION = '0.0200';
+$Plack::Middleware::LogHarakiri::VERSION = '0.0201';
 use parent qw/ Plack::Middleware Process::SizeLimit::Core /;
 
-$Plack::Middleware::LogHarakiri::VERSION = '0.0200';
+use strict;
+use warnings;
+
+$Plack::Middleware::LogHarakiri::VERSION = '0.0201';
 
 =head1 NAME
 
